@@ -121,7 +121,7 @@ def load_fips_test_module(file_name):
                 if comp in ('X', 'Y'):
                     setattr(tv, comp, long(res.group(1), 16))
                 else:
-                    setattr(tv, comp, unhexlify(res.group(1)))
+                    setattr(tv, comp, unhexlify(b(res.group(1))))
                 line = '\n'
             setattr(tv, 'Signature', tv.R + tv.S)
 
@@ -550,7 +550,7 @@ class Det_DSA_Tests(unittest.TestCase):
               "62e862272f"))
 
         # Test _bits2octets
-        h1 = SHA256.new("sample").digest()
+        h1 = SHA256.new(b("sample")).digest()
         self.assertEqual(hexlify(signer._bits2octets(h1)),
             b("01795edf0d54db760f156d0dac04c032"
               "2b3a204224"))
